@@ -18,17 +18,7 @@ from __future__ import print_function
 import logging
 import traceback
 
-from ._logging import (
-    ADD_SYMLINK_ERROR,
-    ADD_TAGS_ERROR,
-    EXPERIMENT_LIVE,
-    INTERNET_CONNECTION_ERROR,
-    INVALID_API_KEY,
-    REGISTER_RPC_FAILED,
-    SEND_NOTIFICATION_FAILED,
-    setup,
-    setup_http_handler,
-)
+from ._logging import setup, setup_http_handler
 from ._reporting import (
     EXPERIMENT_CREATED,
     EXPERIMENT_CREATION_DURATION,
@@ -37,7 +27,7 @@ from ._reporting import (
 from ._typing import Any, Dict, Optional
 from .api import API, APIExperiment
 from .comet import Streamer, format_url, generate_guid, is_valid_experiment_key
-from .config import (  # noqa
+from .config import (
     get_api_key,
     get_config,
     get_global_experiment,
@@ -62,6 +52,7 @@ from .loggers.fastai_logger import patch as fastai_patch
 from .loggers.keras_logger import patch as keras_patch
 from .loggers.lightgbm_logger import patch as lgbm_patch
 from .loggers.mlflow_logger import patch as mlflow_patch
+from .loggers.prophet_logger import patch as prophet_patch
 from .loggers.pytorch_logger import patch as pytorch_patch
 from .loggers.shap_logger import patch as shap_patch
 from .loggers.sklearn_logger import patch as sklearn_patch
@@ -69,9 +60,18 @@ from .loggers.tensorboard_logger import patch as tb_patch
 from .loggers.tensorflow_logger import patch as tf_patch
 from .loggers.tfma_logger import patch as tfma_patch
 from .loggers.xgboost_logger import patch as xg_patch
-from .logging_messages import ONLINE_EXPERIMENT_THROTTLED
+from .logging_messages import (
+    ADD_SYMLINK_ERROR,
+    ADD_TAGS_ERROR,
+    EXPERIMENT_LIVE,
+    INTERNET_CONNECTION_ERROR,
+    INVALID_API_KEY,
+    ONLINE_EXPERIMENT_THROTTLED,
+    REGISTER_RPC_FAILED,
+    SEND_NOTIFICATION_FAILED,
+)
 from .monkey_patching import CometModuleFinder
-from .offline import OfflineExperiment
+from .offline import ExistingOfflineExperiment, OfflineExperiment
 from .optimizer import Optimizer
 from .rpc import create_remote_call, get_remote_action_definition
 from .utils import (
@@ -90,8 +90,10 @@ __all__ = [
     "ConfusionMatrix",
     "Embedding",
     "ExistingExperiment",
+    "ExistingOfflineExperiment",
     "Experiment",
     "get_comet_api_client",
+    "get_global_experiment",
     "Histogram",
     "OfflineExperiment",
     "Optimizer",
@@ -112,6 +114,7 @@ if not get_config("comet.disable_auto_logging"):
     mlflow_patch(MODULE_FINDER)
     xg_patch(MODULE_FINDER)
     tfma_patch(MODULE_FINDER)
+    prophet_patch(MODULE_FINDER)
     shap_patch(MODULE_FINDER)
     lgbm_patch(MODULE_FINDER)
     MODULE_FINDER.start()
