@@ -31,6 +31,7 @@ from everett.manager import (
     parse_bool,
 )
 
+from ._logging import _get_comet_logging_config
 from ._typing import Any, Dict, List, Optional
 from .utils import log_once_at_level
 
@@ -596,6 +597,7 @@ CONFIG_MAP = {
     "comet.logging.file": {"type": str},
     "comet.logging.file_level": {"type": str, "default": "INFO"},
     "comet.logging.file_overwrite": {"type": bool, "default": False},
+    "comet.logging.hide_api_key": {"type": bool, "default": True},
     "comet.logging.console": {"type": str},
     "comet.logging.metrics_ignore": {
         "type": list,
@@ -698,9 +700,15 @@ def get_config(setting=None):
 
 def get_api_key(api_key, config):
     if api_key is None:
-        return config["comet.api_key"]
+        final_api_key = config["comet.api_key"]
     else:
-        return api_key
+        final_api_key = api_key
+
+    # Hide api keys from the log
+    if final_api_key and config.get_bool(None, "comet.logging.hide_api_key") is True:
+        _get_comet_logging_config().redact_string(final_api_key)
+
+    return final_api_key
 
 
 def get_display_summary_level(display_summary_level, config):
