@@ -29,10 +29,10 @@ import signal
 import sys
 import threading
 
-from comet_ml._logging import NATIVE_STD_WRAPPER_NOT_AVAILABLE, UNKOWN_STD_WRAPPER_SPEC
-
 from six.moves import queue
 
+from .logging_messages import NATIVE_STD_WRAPPER_NOT_AVAILABLE, UNKOWN_STD_WRAPPER_SPEC
+
 # -------------------------------------------------
 # These are triggers for keras and tensorflow.keras
 # (respectively) to use their nice progress meters:
