@@ -16,9 +16,9 @@ import logging
 
 import wrapt
 
-from .._logging import check_module
 from .._typing import Any
 from ..experiment import BaseExperiment
+from ..monkey_patching import check_module
 
 LOGGER = logging.getLogger(__name__)
 
