@@ -238,7 +238,6 @@ class SystemDetailsMessage(BaseMessage):
         hostname,  # type: str
         ip,  # type: str
         machine,  # type: str
-        network_interfaces_ips,  # type: List[str]
         os_release,  # type: str
         os_type,  # type: str
         os,  # type: str
@@ -256,7 +255,6 @@ class SystemDetailsMessage(BaseMessage):
         self.hostname = hostname
         self.ip = ip
         self.machine = machine
-        self.network_interfaces_ips = network_interfaces_ips
         self.os = os
         self.os_release = os_release
         self.os_type = os_type
