@@ -24,10 +24,34 @@ import types
 
 import six
 
-from .config import get_global_experiment
+from .config import get_config, get_global_experiment
+from .logging_messages import COMET_DISABLED_AUTO_LOGGING_MSG
 
 LOGGER = logging.getLogger(__name__)
 
+ALREADY_IMPORTED_MODULES = set()
+
+
+def check_module(module):
+    """
+    Check to see if a module has already been loaded.
+    This is an error, unless comet.disable_auto_logging == 1
+    """
+    if get_config("comet.disable_auto_logging"):
+        LOGGER.debug(COMET_DISABLED_AUTO_LOGGING_MSG % module)
+    elif module in sys.modules:
+        ALREADY_IMPORTED_MODULES.add(module)
+
+
+def is_module_already_imported(module):
+    return module in ALREADY_IMPORTED_MODULES
+
+
+def _reset_already_imported_modules():
+    # Modify the set in place to be sure to keep the same reference every
+    # where
+    ALREADY_IMPORTED_MODULES.clear()
+
 
 def get_pep_302_importer(path):
     """ A pep 302 compatible importer
