@@ -17,12 +17,12 @@ import json
 import logging
 import os
 
-from ._logging import OPTIMIZER_KWARGS_CONSTRUCTOR_DEPRACETED
 from ._typing import Any, Dict, Optional
 from .config import get_api_key, get_config
 from .connection import get_optimizer_api
 from .exceptions import InvalidOptimizerParameters, OptimizerException
 from .experiment import BaseExperiment
+from .logging_messages import OPTIMIZER_KWARGS_CONSTRUCTOR_DEPRACETED
 from .predictor import Predictor
 
 LOGGER = logging.getLogger(__name__)
